package view;

import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.ResourceBundle;

import javafx.beans.property.StringProperty;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.*;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.scene.input.MouseEvent;
import model.*;

public class TreeViewCtrl extends FXMLView {
    @FXML
    private TreeView<CapteurAbstrait> treeView;

    private ArrayList<CapteurAbstrait> capteurAbstraits;


    public TreeViewCtrl(ArrayList<CapteurAbstrait> capteurs, String url, String title) throws IOException {
        super(url,title);
        this.capteurAbstraits = capteurs;

        TreeItem<CapteurAbstrait> root = new TreeItem<>();
        treeView.setShowRoot(false);
        root.setExpanded(true);
        //treeView.setRoot(root);
        TreeItemFactoryVisitor treeItemFactoryVisitor = new TreeItemFactoryVisitor();

        treeView.setVisible(true);

        if (root != null && treeView != null) {
            treeView.setRoot(root);
            for (CapteurAbstrait capteur : capteurAbstraits) {
                TreeItem<CapteurAbstrait> item = capteur.accept(treeItemFactoryVisitor);
                root.getChildren().add(item);
            }
        }
//        for(CapteurAbstrait capteur: capteurAbstraits){
//            TreeItem<CapteurAbstrait> item = capteur.accept(treeItemFactoryVisitor);
//            root.getChildren().add(item);
//        }
        this.initializeCapteur();

    }

    public void initializeCapteur() {
        treeView.setCellFactory(param -> new TreeCell<CapteurAbstrait>() {
            @Override
            protected void updateItem(CapteurAbstrait capteur, boolean empty) {
                super.updateItem(capteur, empty);
                if (empty || capteur == null) {
                    textProperty().unbind();
                    setText("");
                } else {
                    textProperty().bind(capteur.getNom());
                    String image = "/images/random.png";
                    if (capteur.getClass() == CapteurVirtuel.class) {
                        image = "/images/virtual.png";
                    } else if (capteur.getClass() == UnitCapteur.class && ((UnitCapteur) capteur).getStrategie().getClass() == StrategyCPU.class) {
                        image = "/images/cpu.png";
                    } else if (capteur.getClass() == UnitCapteur.class && ((UnitCapteur) capteur).getStrategie().getClass() == StrategyRandom.class) {
                        image = "/images/random.png";
                    }

                    setGraphic(new ImageView(new Image(image)) {{
                        setFitHeight(40);
                        setFitWidth(40);
                    }});
                }
            }
        });
    }
}
